==> kube-integration-1.15.8.tgz: package/lib/helm/release/helm3/pool.js <==
const Promise = require('bluebird');
const Release = require('./release');
const Revision = require('./revision');


class ReleasePool {

    constructor({ secrets }){
        this._secrets = secrets;
        this._releases = [];
    }

    isReleaseExistInPool(name){
        return !!this.getReleaseFromPool(name);
    }

    getReleaseFromPool(name){
        return this._releases.find(re => re.name === name);
    }

    addReleaseToPool(release){
        this._releases.push(release);
    }

    getAllReleases(){
        return this._releases;
    }

    createReleaseFromRevision(revision, tillerNamespace){
        return new Release(revision, tillerNamespace);
    }

    prepareReleases() {
        return Promise.map(this._secrets, (secret) => {
            return this._readRevisionDataFromSecret(secret)
                .then((revision) => {
                    const name = revision.name
                    if (!this.isReleaseExistInPool(name)) {
                        const release = this.createReleaseFromRevision(revision, secret.getNamespace());
                        this.addReleaseToPool(release);
                    } else {
                        const release = this.getReleaseFromPool(name);
                        release.addRevision(revision);
                    }
                })
                .catch(err => {
                    console.log(err);
                });
        });
    }



    _readRevisionDataFromSecret(secret){
        const rawName = secret.getMetadata().name;
        const labels = secret.getLabels();
        const dataAsBase64 = secret.getProperty('data.release');
        const revision = new Revision(Object.assign({
            rawName,
            dataAsBase64
        }, labels));
        return revision.init()
            .then(() => revision);
    }

}

module.exports = ReleasePool;

==> kube-integration-1.15.9.tgz: package/lib/helm/release/helm3/pool.js <==
const Promise = require('bluebird');
const Release = require('./release');
const Revision = require('./revision');


class ReleasePool {

    constructor({ secrets }){
        this._secrets = secrets;
        this._releases = [];
        this._versions = {};
    }

    isReleaseExistInPool(name){
        return !!this.getReleaseFromPool(name);
    }

    needProcessRevision(actualVersion, revision) {
        return actualVersion < revision._version;
    }


    getReleaseFromPool(name){
        return this._releases.find(re => re.name === name);
    }

    addReleaseToPool(release){
        this._releases.push(release);
    }

    getAllReleases(){
        return this._releases;
    }

    createReleaseFromRevision(revision, tillerNamespace){
        return new Release(revision, tillerNamespace);
    }

    getIgnoredRevisions() {
        return this._versions;
    }

    prepareReleasesWithOptimization(actualVersions = {}) {
        return Promise.map(this._secrets, (secret) => {
            return this._readRevisionDataFromSecret(secret)
                .then((revision) => {
                    const name = revision.name;
                    const actualVersion = actualVersions[name] || -1;
                    if(this.needProcessRevision(actualVersion, revision)) {
                        if (!this.isReleaseExistInPool(name)) {
                            const release = this.createReleaseFromRevision(revision, secret.getNamespace());
                            this.addReleaseToPool(release);
                        } else {
                            const release = this.getReleaseFromPool(name);
                            release.addRevision(revision);
                        }
                    } else {
                        if(!this._versions[name]) {
                            this._versions[name] = [];
                        }
                        this._versions[name].push(revision._version);
                    }
                })
                .catch(err => {
                    console.log(err);
                });
        });
    }

    prepareReleases() {
        return Promise.map(this._secrets, (secret) => {
            return this._readRevisionDataFromSecret(secret)
                .then((revision) => {
                    const name = revision.name;
                    if (!this.isReleaseExistInPool(name)) {
                        const release = this.createReleaseFromRevision(revision, secret.getNamespace());
                        this.addReleaseToPool(release);
                    } else {
                        const release = this.getReleaseFromPool(name);
                        release.addRevision(revision);
                    }
                })
                .catch(err => {
                    console.log(err);
                });
        });
    }



    _readRevisionDataFromSecret(secret){
        const rawName = secret.getMetadata().name;
        const labels = secret.getLabels();
        const dataAsBase64 = secret.getProperty('data.release');
        const revision = new Revision(Object.assign({
            rawName,
            dataAsBase64
        }, labels));
        return revision.init()
            .then(() => revision);
    }

}

module.exports = ReleasePool;
